#!/usr/bin/env sh
# SPDX-License-Identifier: AGPL-3.0-or-later
# SPDX-FileCopyrightText: 2021-2024 JayVii <jayvii[AT]posteo[DOT]de>

# $1 - HTML Root
# $2 - prv/pub
# $3 - repo name
# $@ - optional list of refs, as given to post-update hook

# Error out if not all options are given
if [ -z "$3" ]; then
    echo "Usage:
git_deploy.sh \\
    \"/var/www/git.example.git\" \\
    \"pub\" \\
    \"stagit-scripts\" \\
    \"refs/tags/v0.0.0\" # optional parameters given by post-update hook
    "
    exit 1;
fi

for REF in ${4}; do

    # Git-Repository
    cd "${1}/${2}/${3}.git"

    # fetch newest tag from given ref
    TAG=`git tag --contains $REF | tail -n 1 | awk '{ print $NF }'`

    # check whether a tag was given
    if [ ! -z $TAG ]; then

        # fetch the archive from previous export via git_export_tarball.sh
        if [ -f "${1}/${2}/${3}/exports/${TAG}.tar.gz" ]; then
        
            # extract archive to temporary directory
            TMPDIR=`mktemp --directory`
            tar xfvz "${1}/${2}/${3}/exports/${TAG}.tar.gz" \
                --directory "${TMPDIR}/" > /dev/null

            MAKE_STATUS=0

            # check whether Makefile exists
            if [ -f "${TMPDIR}/Makefile" ]; then

                # check whether Makefile contains the git-hook-deploy rule
                if [ ! -z $(grep "git-hook-deploy" "${TMPDIR}/Makefile") ]; then

                    # run deployment
                    cd "$TMPDIR"
                    make git-hook-deploy > /dev/null
                    MAKE_STATUS=$?

                    # User output
                    if [ $MAKE_STATUS = 0 ]; then
                        echo "Version ${TAG} has been deployed"
                    fi

                fi

            fi

            # clean up
            rm -r "$TMPDIR"

            # error handling
            if [ $MAKE_STATUS -gt 0 ]; then
                exit 1
            fi

        fi

    fi

done

